<?php
/**
 * This file belongs to the YIT Framework.
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

/**
 * Return an array with the options for Theme Options > Typography and Color > Buttons
 *
 * @package Yithemes
 * @author Andrea Grillo <andrea.grillo@yithemes.com>
 * @author Antonio La Rocca <antonio.larocca@yithemes.it>
 * @since 2.0.0
 * @return mixed array
 *
 */
return array(

    /* Typography and Color > Buttons */
    array(
        'type' => 'title',
        'name' => __( 'Buttons Flat', 'yit' ),
        'desc' => ''
    ),

    array(
        'id' => 'button-font',
        'type' => 'typography',
        'name' => __( 'Buttons Typography', 'yit' ),
        'desc' => __( 'Select the font, color and size for buttons text.', 'yit' ),
        'min' => 1,
        'max' => 80,
        'default_font_id' => 'typography-website-paragraph',
        'std'   => array(
            'size'      => 14,
            'unit'      => 'px',
            'family'    => 'default',
            'style'     => '700',
            'color'     => '#000000',
            'align'     => 'center',
            'transform' => 'uppercase',
        ),
        'style' => array(
            'selectors'   => '.btn-flat, a.btn-flat,
                              .nav ul > li div div.btn-fb-login a,
                              #welcome-menu-login.nav ul > li #customer_login .button,
                              .yith-wcwl-add-button .add_to_wishlist,
                              .yith-wcwl-add-button .add_to_wishlist:before,
                              div.compare a.compare,
                              div.compare a.compare:before,
                              .yith-wcwl-wishlistaddedbrowse a,
                              .yith-wcwl-wishlistexistsbrowse a,
                              a.button.view,
                              .banner-image .button,
                              .wishlist_table .button,
                              .woocommerce.woocommerce-wishlist .yith-wcwl-wishlist-search-form button.wishlist-search-button,
                              a.btn.animated.btn-flat:hover,
                              table.compare-list .add-to-cart td a,
                              a.bp-title-button,
                              .widget.widget_price_filter button[type="submit"],
                              a.compare.button,
                              .yit-maintenance-mode form.newsletter input.submit-field,
                              .cx-send a.cx-form-btn,
                              .woocommerce div.product-actions div.yith-ywraq-add-to-quote a.add-request-quote-button,
                              .woocommerce div.product-actions div.yith-ywraq-add-to-quote a.add-request-quote-button:before,
                              .yith_ywraq_add_item_response_message,
                              .yith_ywraq_add_item_browse_message a,
                              ul.products li.product .product-meta .product-meta-wrapper .yith-ywraq-add-to-quote .yith-ywraq-add-button .add-request-quote-button.button',
            'properties'  => 'font-size,
                              font-family,
                              font-weight,
                              color,
                              text-transform,
                              text-align'
        ),
        
    ),

    array(
        'id' => 'button-hover-color',
        'type' => 'colorpicker',
        'name' => __( 'Buttons color hover', 'yit' ),
        'desc' => __( 'Select a text color hover for the buttons of all pages.', 'yit' ),
        'std'  => array(
            'color' => '#ffffff'
        ),
        'style' => array(
            'selectors'   => '.btn-flat:hover,
                              .nav ul > li div div.btn-fb-login a:hover,
                              a.btn-flat:hover,
                              #welcome-menu-login.nav ul > li #customer_login .button:hover,
                              .woocommerce.woocommerce-wishlist .yith-wcwl-wishlist-search-form button.wishlist-search-button:hover,
                              .yith-wcwl-add-button .add_to_wishlist:hover,
                              .yith-wcwl-add-button .add_to_wishlist:hover:before,
                              div.compare a.compare:hover,
                              div.compare a.compare:hover:before,
                               .yith-wcwl-wishlistaddedbrowse a:hover,
                               .yith-wcwl-wishlistexistsbrowse a:hover,
                               a.button.view:hover,
                               table.compare-list .add-to-cart td a:hover,
                               .widget.widget_price_filter button[type="submit"]:hover,
                               .yith-wcwl-wishlistaddedbrowse .feedback,
                               a.compare.button:hover,
                               .woocommerce a.button.wc-forward.btn-flat:hover,
                               a.button.wc-forward.btn-flat:hover,
                               .yit-maintenance-mode form.newsletter input.submit-field:hover,
                               .cx-send a.cx-form-btn:hover,
                               .woocommerce div.product-actions div.yith-ywraq-add-to-quote a:not(.button).add-request-quote-button:hover,
                               .woocommerce div.product-actions div.yith-ywraq-add-to-quote a:not(.button).add-request-quote-button:hover:before',
            'properties'  => 'color'
        ),
        
    ),

    array(
        'id' => 'button-background-color',
        'type' => 'colorpicker',
        'variations' => array(
            'normal' => __( 'Background color', 'yit' ),
            'hover' => __( 'Background hover color', 'yit ')
        ),
        'name' => __( 'Buttons background color', 'yit' ),
        'desc' => __( 'Select a color for the buttons background of all pages.', 'yit' ),
        'std'  => array(
			'color' => array(
				'normal' => 'transparent',
				'hover' => '#818e49'
			)
		),
        'style' => array(
            'normal' => array(
                'selectors'   => '.btn-flat,
                                   a.btn-flat,
                                   button.button-login,
                                   .nav ul > li div div.btn-fb-login,
                                   .banner-image .button,
                                   #welcome-menu-login.nav ul > li #customer_login .button,
                                   .yith-wcwl-add-button .add_to_wishlist,
                                   div.compare a.compare, a.button.view,
                                   .wishlist_table .button,
                                   .woocommerce.woocommerce-wishlist .yith-wcwl-wishlist-search-form button.wishlist-search-button,
                                   a.btn.animated.btn-flat,
                                   a.btn.animated.btn-flat:hover,
                                   table.compare-list .add-to-cart td a,
                                  .widget.widget_price_filter button[type="submit"],
                                  a.compare.button,
                                  .yit-maintenance-mode form.newsletter input.submit-field,
                                  .cx-send a.cx-form-btn,
                                  .woocommerce div.product-actions div.yith-ywraq-add-to-quote a.add-request-quote-button',
                'properties'  => 'background-color, background'
            ),
            'hover' => array(
                'selectors'   => '.btn-flat:hover, a.btn-flat:hover, .nav ul > li div div.btn-fb-login:hover, #welcome-menu-login.nav ul > li #customer_login .button:hover, .yith-wcwl-add-button .add_to_wishlist:hover, div.compare a.compare:hover,
                                .woocommerce div.product-actions div.wishlist .yith-wcwl-wishlistaddedbrowse a:hover, .woocommerce div.product-actions div.wishlist .yith-wcwl-wishlistexistsbrowse a:hover, a.button.view:hover, #yith-wcwl-form a.button:hover,.woocommerce.woocommerce-wishlist .yith-wcwl-wishlist-search-form button.wishlist-search-button:hover, table.compare-list .add-to-cart td a:hover,
                                .widget.widget_price_filter button[type="submit"]:hover,
                                .yith-wcwl-wishlistaddedbrowse .feedback,
                                a.compare.button:hover,
                                .woocommerce a.button.wc-forward.btn-flat:hover,
                                a.button.wc-forward.btn-flat:hover,
                                .yit-maintenance-mode form.newsletter input.submit-field:hover,
                                .cx-send a.cx-form-btn:hover,
                                .woocommerce div.product-actions div.yith-ywraq-add-to-quote a.add-request-quote-button:hover',
                'properties'  => 'background-color, background'
            )
        ),
        
    ),

    array(
        'id' => 'button-border-color',
        'type' => 'colorpicker',
        'variations' => array(
            'normal' => __( 'Border color', 'yit' ),
            'hover' => __( 'Border hover color', 'yit' )
        ),
        'name' => __( 'Buttons border color', 'yit' ),
        'desc' => __( 'Select a color for the buttons border of all pages.', 'yit' ),
        'std'  => array(
            'color' => array(
                'normal' => '#929688',
                'hover' => '#929688'
            )
        ),
        'style' => array(
            'normal' => array(
                'selectors'   => '.btn-flat, a.btn-flat, .yith-wcwl-add-button .add_to_wishlist, .banner-image .button, div.compare a.compare, .nav ul > li div div.btn-fb-login, .yith-wcwl-wishlistaddedbrowse a, .yith-wcwl-wishlistexistsbrowse a, a.button.view, .wishlist_table .button,.woocommerce.woocommerce-wishlist .yith-wcwl-wishlist-search-form button.wishlist-search-button, a.btn.animated.btn-flat, a.btn.animated.btn-flat:hover, table.compare-list .add-to-cart td a,
                                 a.bp-title-button, .widget.widget_price_filter button[type="submit"],
                                 a.compare.button, #welcome-menu-login.nav ul > li #customer_login .button,
                                 .yit-maintenance-mode form.newsletter input.submit-field,
                                 .cx-send a.cx-form-btn,
                                 .woocommerce div.product-actions div.yith-ywraq-add-to-quote a.add-request-quote-button',
                'properties'  => 'border-color'
            ),
            'hover' => array(
                'selectors'   => '.btn-flat:hover, a.btn-flat:hover, .yith-wcwl-add-button .add_to_wishlist:hover, .banner-image .button:hover, div.compare a.compare:hover, .nav ul > li div div.btn-fb-login:hover, .yith-wcwl-wishlistaddedbrowse a:hover, .yith-wcwl-wishlistexistsbrowse a:hover, a.button.view:hover, table.compare-list .add-to-cart td a:hover,
                                 .widget.widget_price_filter button[type="submit"]:hover,
                                 .yith-wcwl-wishlistaddedbrowse .feedback:after,
                                 a.compare.button:hover,
                                 .yit-maintenance-mode form.newsletter input.submit-field:hover,
                                 #welcome-menu-login.nav ul > li #customer_login .button:hover,
                                 .cx-send a.cx-form-btn:hover,
                                 .woocommerce div.product-actions div.yith-ywraq-add-to-quote a.add-request-quote-button:hover',
                'properties'  => 'border-color'
            )
        ),
        
    ),

    /* ========= Button Alternative =========== */
    array(
        'type' => 'title',
        'name' => __( 'Buttons Alternative', 'yit' ),
        'desc' => ''
    ),

    array(
        'id' => 'button-font-alternative',
        'type' => 'typography',
        'name' => __( 'Buttons Typography', 'yit' ),
        'desc' => __( 'Select the font, color and size for buttons text.', 'yit' ),
        'min' => 1,
        'max' => 80,
        'default_font_id' => 'typography-website-paragraph',
        'std'   => array(
            'size'      => 14,
            'unit'      => 'px',
            'family'    => 'default',
            'style'     => '700',
            'color'     => '#ffffff',
            'align'     => 'center',
            'transform' => 'uppercase',
        ),
        'style' => array(
            'selectors'   => '.btn-alternative,
                              a.btn-alternative,
                              #welcome-menu-login.nav ul > li #customer_login .button.button-register,
                              #submit,
                              .button,
                              a.btn.animated.btn-alternative:hover,
                              #comments ol li .information .user-info .is_author,
                              .woocommerce-page #reviews div.reply > a',
            'properties'  => 'font-size,
                              font-family,
                              font-weight,
                              color,
                              text-transform,
                              text-align'
        ),
        
    ),

    array(
        'id' => 'button-hover-color-alternative',
        'type' => 'colorpicker',
        'name' => __( 'Buttons color hover', 'yit' ),
        'desc' => __( 'Select a text color hover for the buttons of all pages.', 'yit' ),
        'std'  => array(
            'color' => '#ffffff'
        ),
        'style' => array(
            'selectors'   => '.btn-alternative:hover,
                              a.btn-alternative:hover,
                              #welcome-menu-login.nav ul > li #customer_login .button.button-register:hover,
                              #submit:hover, .button:hover,
                              #my-account-sidebar .user-profile span.logout a,
                              #my-account-content .addresses .title a.edit',
            'properties'  => 'color'
        ),
        
    ),

    array(
        'id' => 'button-background-color-alternative',
        'type' => 'colorpicker',
        'variations' => array(
            'normal' => __( 'Background color', 'yit' ),
            'hover' => __( 'Background hover color', 'yit ')
        ),
        'linked_to' => array(
            'normal' => 'theme-color-1'
        ),
        'name' => __( 'Buttons background color', 'yit' ),
        'desc' => __( 'Select a color for the buttons background of all pages.', 'yit' ),
        
        'std'  => array(
			'color' => array(
				'normal' => '#888984',
				'hover' => '#818e49'
			)
		),
        'style' => array(
            'normal' => array(
                'selectors'   => '.btn-alternative,
                                  a.btn-alternative,
                                  #welcome-menu-login.nav ul > li #customer_login .button.button-register,
                                  #submit, .button,
                                  .woocommerce input.button,
                                  .button.submit-field,
                                  a.btn.animated.btn-alternative:hover,
                                  .woocommerce.widget.widget_product_search #searchform #searchsubmit,
                                  #yith-searchsubmit,
                                  #my-account-sidebar .user-profile span.logout,
                                  #my-account-content .addresses .title a.edit,
                                  #comments ol li .information .user-info .is_author',
                'properties'  => 'background-color, background'
            ),
            'hover' => array(
                'selectors'   => '.btn-alternative:hover,
                                  a.btn-alternative:hover,
                                  #welcome-menu-login.nav ul > li #customer_login .button.button-register:hover,
                                  #submit:hover,
                                  .woocommerce #respond input#submit:hover,
                                  .button:hover,
                                  .woocommerce input.button:hover,
                                  .button.submit-field:hover,
                                  .woocommerce .btn-alternative.button.checkout:hover,
                                  .woocommerce a.btn-alternative.button.checkout:hover,
                                  .woocommerce.widget.widget_product_search #searchform #searchsubmit:hover,
                                  #yith-searchsubmit:hover,
                                  #my-account-sidebar .user-profile span.logout:hover,
                                  #my-account-content .addresses .title a.edit:hover',
                'properties'  => 'background-color, background'
            )
        )
    ),

    array(
        'id' => 'button-border-color-alternative',
        'type' => 'colorpicker',
        'variations' => array(
            'normal' => __( 'Border color', 'yit' ),
            'hover' => __( 'Border hover color', 'yit' )
        ),
        'linked_to' => array(
            'normal' => 'theme-color-2'
        ),
        
        'name' => __( 'Buttons border color', 'yit' ),
        'desc' => __( 'Select a color for the buttons border of all pages.', 'yit' ),
        'std'  => array(
            'color' => array(
                'normal' => '#888984',
                'hover' => '#929688'
            )
        ),
        'style' => array(
            'normal' => array(
                'selectors'   => '.btn-alternative,
                                  a.btn-alternative,
                                  #welcome-menu-login.nav ul > li #customer_login .button.button-register,
                                  #submit,
                                  .button,
                                  a.btn.animated.btn-alternative:hover',
                'properties'  => 'border-color'
            ),
            'hover' => array(
                'selectors'   => '.btn-alternative:hover,
                                 a.btn-alternative:hover,
                                 #welcome-menu-login.nav ul > li #customer_login .button.button-register:hover,
                                 #submit:hover,
                                 .button:hover',
                'properties'  => 'border-color'
            )
        )
    )
);

